@@ -9,7 +9,7 @@ config_dir: setup of directory ~/.pyTEMlib for custom sources and database
 import os
 import shutil
 
-config_files = ['TEMlibrc', 'microscopes.csv', 'edges_db.csv', 'edges_db.pkl', 'fparam.txt']
+config_files = ['microscopes.csv', 'edges_db.csv', 'edges_db.pkl', 'fparam.txt']
 data_path = os.sep.join([os.path.dirname(__file__), 'data'])
 
 if os.name == 'posix':
@@ -23,7 +23,7 @@ else:
 if os.path.isdir(config_path) is False:
     # messages.information("Creating config directory: %s" % config_path)
     os.mkdir(config_path)
-    
+
 for file in config_files:
     templates_file = os.path.join(data_path, file)
     config_file = os.path.join(config_path, file)
